/**
 * Test file for the ADXL202EB accelerometer class
 *
 * <P>Shows the different kinds of information you can use the class to
 * recieve from the ADXL202EB.
 *
 * <P><U>NETLIST for Headers on ADXL202EB:</U>            <BR>
 * Pin E -> +5V (Vcc)                                     <BR>
 * Pin C (Y-Axis Output) -> Pin 11 on Javelin Stamp       <BR>
 * Pin D (X-Axis Output) -> Pin 10 on Javelin Stamp       <BR>
 * Pin B (Self-Test) -> Not Connected                     <BR>
 * Pin A -> GND (Vss)                                     <BR>
 *
 * @version - 1.00 Initial test file
 * @author  - Blake Robertson
 */

 import stamp.core.*;
import stamp.peripheral.mems.ADXL202EB;

public class testADXL202EB
{
  public static void main()
  {
    ADXL202EB accelerometer = new ADXL202EB( 10, 11 );

    int dutyX, dutyY; // variables which will store duty cycle percentage
    int gForceX, gForceY;    // variables for int gForce representation

    while(true)
    {
      // How to retrieve duty factor information from the ADXL202EB
      dutyX = accelerometer.findDutyFactor('x'); // param 'x' specifies x axis
      dutyY = accelerometer.findDutyFactor('y'); // param 'y' specifies y axis

      // How to retrieve an integer representation of the gForce
      gForceX = accelerometer.findGForce('x');
      gForceY = accelerometer.findGForce('y');

      // Output for variables
      System.out.println("Duty Cycle %");
      System.out.print( "DutyX = " );
      System.out.print( dutyX );
      System.out.print( "  DutyY = ");
      System.out.print( dutyY );
      System.out.print( "\n\n");

      System.out.println( "G Force (m/s^2)" );

      System.out.print( "gForceX (int, string): " );
      System.out.print( gForceX );
      System.out.print( ", ");
      // To format the gForce to a floating point number use the toGForceStr
      // method.  See JavaDocs on GForceStr for more information.
      System.out.println( accelerometer.toGForceStr( gForceX ) );

      System.out.print( "gForceY (int, string): " );
      System.out.print( gForceY );
      System.out.print( ", ");
      // To format the gForce to a floating point number use the toGForceStr
      // method.  See JavaDocs on GForceStr for more information.
      System.out.println( accelerometer.toGForceStr( gForceY ) );

      CPU.delay( 30000 );  // Long delay - to see it update faster make this
                           // number like 10000.

      System.out.print('\u0010');  // Clears the terminal
    }
  }
}