/**
 * Basic test file for the Memsic accelerometer class.  Shows the
 * different kinds of information you can use the class to
 * recieve from the Memsic2125.
 *
 * NOTE: This file doesn't take advantage of the tempature output
 * pin of the chip.  See other test files for a reading tempature
 * from the Memsic2125.
 *
 * <P><U>NETLIST for Headers on Memsic2125</U>            <BR>
 * Pin 1 (Temp Out) -> Not Connected                      <BR>
 * Pin 2 (Y-Axis Output) -> Pin 9 on Javelin Stamp        <BR>
 * Pin 3 -> GND (Vss)                                     <BR>
 * Pin 4 -> GND (Vss)                                     <BR>
 * Pin 5 (X-Axis Output) -> Pin 8 on Javelin Stamp        <BR>
 * Pin 6 -> +5V (Vcc)                                     <BR>
 *
 * @version - 1.00 Initial test file
 * @author  - Blake Robertson
 */
import stamp.core.*;
import stamp.peripheral.mems.Memsic2125;

public class testMemsic2125
{
  public static void main()
  {
    Memsic2125 accelerometer = new Memsic2125( 8, 9 );

    int dutyX, dutyY; // variables which will store duty cycle percentage
    int gForceX, gForceY;    // variables for int gForce representation

    while(true)
    {
      // How to retrieve duty factor information from the Memsic2125
      dutyX = accelerometer.findDutyFactor('x'); // param 'x' specifies x axis
      dutyY = accelerometer.findDutyFactor('y'); // param 'y' specifies y axis

      // How to retrieve an integer representation of the gForce
      gForceX = accelerometer.findGForce('x');
      gForceY = accelerometer.findGForce('y');

      // Output for variables
      System.out.println("Duty Cycle %");
      System.out.print( "DutyX = " );
      System.out.print( dutyX );
      System.out.print( "  DutyY = ");
      System.out.print( dutyY );
      System.out.print( "\n\n");

      System.out.println( "G Force (m/s^2)" );

      System.out.print( "gForceX (int, string): " );
      System.out.print( gForceX );
      System.out.print( ", ");
      // To format the gForce to a floating point number use the toGForceStr
      // method.  See JavaDocs on GForceStr for more information.
      System.out.println( accelerometer.toGForceStr( gForceX ) );

      System.out.print( "gForceY (int, string): " );
      System.out.print( gForceY );
      System.out.print( ", ");
      // To format the gForce to a floating point number use the toGForceStr
      // method.  See JavaDocs on GForceStr for more information.
      System.out.println( accelerometer.toGForceStr( gForceY ) );

      CPU.delay( 30000 );  // Long delay - to see it update faster make this
                           // number like 10000.

      System.out.print('\u0010');  // Clears the terminal
    }
  }
}