/**
 * This test file shows how you can use the temperature out pin on
 * the memsic2125 with an Analog to Digital converter (This particular
 * test file uses the LTC1298) to get readings in degrees celcius or
 * fahrenheit.
 *
 *
 * <P><U>NETLIST for Headers on Memsic2125</U>            <BR>
 * Pin 1 (Temp Out) -> Pin 2 (channel 0 In) on LTC1298    <BR>
 * Pin 2 (Y-Axis Output) -> Pin 9 on Javelin Stamp        <BR>
 * Pin 3 -> GND (Vss)                                     <BR>
 * Pin 4 -> GND (Vss)                                     <BR>
 * Pin 5 (X-Axis Output) -> Pin 8 on Javelin Stamp        <BR>
 * Pin 6 -> +5V (Vcc)                                     <BR>
 *
 * See schematic file for how to hookup the LTC1298
 *
 * @version - 1.00 Initial test file
 * @author  - Blake Robertson
 */
import stamp.core.*;
import stamp.peripheral.mems.Memsic2125;
import stamp.peripheral.io.ADC.LTC1298;

public class testMemsic2125TempOutLTC1298
{
  public static void main()
  {
    // Create a new object with Xaxis, Yaxis on pins 8,9 respectively
    Memsic2125 accelerometer = new Memsic2125( 8, 9 );

    // Create a new LTC1298 object: pin1=data, pin2=clock, pin4=Chip Select
    LTC1298 adc = new LTC1298(CPU.pin1,CPU.pin2,CPU.pin4);

    int tempOutMV;

    while(true)
    {
      adc.read(0);  // reads the value from channel 0 of LTC1298
      tempOutMV = adc.lastMV();

      System.out.print("MV Reading from ADC = ");
      System.out.println( tempOutMV );

      System.out.print("Reading converted to degrees C = ");
      System.out.println( accelerometer.formatTempC( tempOutMV ) );

      System.out.print("Reading converted to degrees F = ");
      System.out.println( accelerometer.formatTempF( tempOutMV ) );

      CPU.delay( 30000 );  // Long delay - to see it update faster make this
                           // number like 10000.
      System.out.print('\u0010');  // Clears the terminal

    }

  }
}