/**
 * Class for the Analog Device's ADXL202EB Accelerometer
 *
 * <P>Class extends the Accelerometer class.  See the Accelerometer
 * class documentation for more information on the methods this class
 * uses.
 *
 * <P>The ADXL202EB class calls the base class constructor with the
 * appropriate scale factor for the ADXL202EB.  No additional
 * methods or overloaded methods were neccessary in this class.  It
 * was written mainly because it's a very popular accelerometer used
 * for prototyping and robotics applications and makes it even easier
 * to add to your application.
 *
 * <P>The ADXL202EB needs no external components.  Connect to the
 * Javelin stamp as mentioned below and you're set.  NOTE: Upon
 * recieving the ADXL202EB there are 2 capacitors and 1 resistor that
 * are required to set the bandwith and the duty cycle period (refered
 * to as T2).  See ADXL202EB datasheet for more information.
 * But if you really want to just get started you could use
 * 0.1uF capacitors for C1 and C2 and for
 * Rset use the equation T2 = Rset / 125MOhms ( you can use a value of
 * 125K for a T2 of 1ms ).
 * <P><U>NETLIST for Headers on ADXL202EB:</U>            <BR>
 * Pin E -> +5V (Vcc)                                     <BR>
 * Pin C (Y-Axis Output) -> Pin 11 on Javelin Stamp       <BR>
 * Pin D (X-Axis Output) -> Pin 10 on Javelin Stamp       <BR>
 * Pin B (Self-Test) -> Not Connected                     <BR>
 * Pin A -> GND (Vss)
 *
 * @version 1.00 Initial development
 */

package stamp.peripheral.mems;

import stamp.core.*;
import stamp.peripheral.mems.Accelerometer;

public class ADXL202EB extends Accelerometer
{
 /**
  * Default Constructor
  */
  public ADXL202EB( int txPinIn, int tyPinIn )
  {
    super( txPinIn, tyPinIn, 125 );  // calls base class constructor
                                     // third argument 125 is the integer
                                     // representation of the scale factor of
                                     // 12.5% of the Memsic2125 accelerometer.
  }

  /**
   * See Accelerometer class docs for inherited methods
   */
}